import { Treeable } from '../../core/treeable/shared/treeable.model';
import { SiteBrowserState } from '../../core/util/site-browser.state';
import { SiteBrowserService } from '../../core/util/site-browser.service';
import { SettingsStorageService } from '../../core/util/settings-storage.service';
import { NotificationService } from '../../core/util/notification.service';
import { FileService } from '../../core/file/file.services';
import { Site } from '../../core/treeable/shared/site.model';
/**
 * The SiteDataTableComponent is a PrimeNG Component which provides a DataTable to display dotCMS Host/Folder Navigation
 * The Component is Supscribed to the [[SiteBrowserState]] to monitor when Folders and Site changes occur
 * In additiont to this it will respond to dragging Files and Folders from the local filesystem and upload them to dotCMS
 * The SiteDataTableComponent is able to display [[Treeable]] assets
 */
export declare class SiteDatatableComponent {
    private updateService;
    private fileService;
    private siteBrowserService;
    private settingsStorageService;
    private messageService;
    dotCMSURL: string;
    site: Site;
    treeables: Treeable[];
    constructor(updateService: SiteBrowserState, fileService: FileService, siteBrowserService: SiteBrowserService, settingsStorageService: SettingsStorageService, messageService: NotificationService);
    /**
     * Listens to the double click event.  If the row clicked is a folder the [[SiteBrowserState]] will be called to
     * change the folder. This will cause this component to load the new folder and of course anyone else
     * subscribed to the [[SiteBrowserState]] folder state
     * @param event
     */
    doubleClick(event: any): void;
    /**
     * On single click of a row this function will update the [[SiteBrowserState]] selected [[Treeable]]
     * @param event
     */
    selectTreeable(event: any): void;
    /**
     * This function is called when the [[SiteBrowserState]] uri is changed
     * @param uri
     */
    loadFolder(uri: string): void;
    /**
     * This function is called when the [[SiteBrowserState]] Site is changed
     * @param siteName
     */
    loadSite(site: Site): void;
    handleDragOver(e: any): void;
    /**
     * Deals with the drop of 1 to many files and folders from the filesystem
     * @param e
     * @returns {boolean}
     */
    handleDrop(e: any): void;
}
export declare class DotSiteDatatableModule {
}
